pub struct LayoutRect {
pub left: f64,
pub top: f64,
pub width: f64,
pub height: f64,
}Fields
left: f64Top-left x coordinate in the layout engine coordinate space.
top: f64Top-left y coordinate in the layout engine coordinate space.
width: f64height: f64Trait Implementations
Sourceimpl Clone for LayoutRect
impl Clone for LayoutRect
Sourcefn clone(&self) -> LayoutRect
fn clone(&self) -> LayoutRect
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for LayoutRect
Sourceimpl Debug for LayoutRect
impl Debug for LayoutRect
Sourceimpl PartialEq for LayoutRect
impl PartialEq for LayoutRect
Sourcefn eq(&self, other: &LayoutRect) -> bool
fn eq(&self, other: &LayoutRect) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for LayoutRect